from jax._src.prng import PRNGKeyArray
from typing import Any


Pytree = Any

PRNGKey = PRNGKeyArray
